aboutsummaryrefslogtreecommitdiff
path: root/src/wallet/feebumper.h
diff options
context:
space:
mode:
authorfurszy <matiasfurszyfer@protonmail.com>2023-09-19 08:09:23 -0300
committerfurszy <matiasfurszyfer@protonmail.com>2023-09-26 20:17:02 -0300
commitb3db8c9d5ccfe5c31341169fa7ac044427122921 (patch)
tree5092edd4c1cb7349c7c90932cc19699080fb2875 /src/wallet/feebumper.h
parent1d4846a8443be901b8a5deb0e357481af22838d0 (diff)
downloadbitcoin-b3db8c9d5ccfe5c31341169fa7ac044427122921.tar.xz
rpc: bumpfee, improve doc for 'reduce_output' arg
The current argument name and description are dangerous as it don't describe the case where the user selects the recipient output as the change address. This one could end up been increased by the inputs minus outputs remainder. Which, when bumpfee adds new inputs to the transaction, leads the process to send more coins to the recipient. Which is not what the user would expect from a 'reduce_output' param naming. Co-authored-by: Murch <murch@murch.one>
Diffstat (limited to 'src/wallet/feebumper.h')
-rw-r--r--src/wallet/feebumper.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/wallet/feebumper.h b/src/wallet/feebumper.h
index f00bf15730..d3d43861ef 100644
--- a/src/wallet/feebumper.h
+++ b/src/wallet/feebumper.h
@@ -44,7 +44,7 @@ bool TransactionCanBeBumped(const CWallet& wallet, const uint256& txid);
* @param[out] mtx The bump transaction itself
* @param[in] require_mine Whether the original transaction must consist of inputs that can be spent by the wallet
* @param[in] outputs Vector of new outputs to replace the bumped transaction's outputs
* @param[in] reduce_output The position of the change output to deduct the fee from in the transaction being bumped
*/
Result CreateRateBumpTransaction(CWallet& wallet,
const uint256& txid,
@@ -55,7 +55,7 @@ Result CreateRateBumpTransaction(CWallet& wallet,
CMutableTransaction& mtx,
bool require_mine,
const std::vector<CTxOut>& outputs,
- std::optional<uint32_t> reduce_output = std::nullopt);
+ std::optional<uint32_t> original_change_index = std::nullopt);
//! Sign the new transaction,
//! @return false if the tx couldn't be found or if it was
@@ -44,7 +44,7 @@ bool TransactionCanBeBumped(const CWallet& wallet, const uint256& txid);
* @param[in] require_mine Whether the original transaction must consist of inputs that can be spent by the wallet
* @param[in] outputs Vector of new outputs to replace the bumped transaction's outputs
- * @param[in] reduce_output The position of the change output to deduct the fee from in the transaction being bumped
+ * @param[in] original_change_index The position of the change output to deduct the fee from in the transaction being bumped
*/
Result CreateRateBumpTransaction(CWallet& wallet,